# nocov start

.onLoad <- function(libname, pkgname) {
  renv$initialize(libname, pkgname)
}

# nocov end
